Page MenuHomePhabricator

D11004.diff
No OneTemporary

D11004.diff

diff --git a/src/applications/home/controller/PhabricatorHomeMainController.php b/src/applications/home/controller/PhabricatorHomeMainController.php
--- a/src/applications/home/controller/PhabricatorHomeMainController.php
+++ b/src/applications/home/controller/PhabricatorHomeMainController.php
@@ -130,6 +130,7 @@
->setViewer($user)
->withStatuses(ManiphestTaskStatus::getOpenStatusConstants())
->withPriorities(array($unbreak_now))
+ ->needProjectPHIDs(true)
->setLimit(10);
$tasks = $task_query->execute();
@@ -173,6 +174,7 @@
->withStatuses(ManiphestTaskStatus::getOpenStatusConstants())
->withPriorities(array($needs_triage))
->withAnyProjects(mpull($projects, 'getPHID'))
+ ->needProjectPHIDs(true)
->setLimit(10);
$tasks = $task_query->execute();
} else {
@@ -269,6 +271,7 @@
->withStatuses(ManiphestTaskStatus::getOpenStatusConstants())
->setGroupBy(ManiphestTaskQuery::GROUP_PRIORITY)
->withOwners(array($user_phid))
+ ->needProjectPHIDs(true)
->setLimit(10);
$tasks = $task_query->execute();
diff --git a/src/applications/maniphest/conduit/ManiphestConduitAPIMethod.php b/src/applications/maniphest/conduit/ManiphestConduitAPIMethod.php
--- a/src/applications/maniphest/conduit/ManiphestConduitAPIMethod.php
+++ b/src/applications/maniphest/conduit/ManiphestConduitAPIMethod.php
@@ -237,6 +237,7 @@
->setViewer($request->getUser())
->withPHIDs(array($task->getPHID()))
->needSubscriberPHIDs(true)
+ ->needProjectPHIDs(true)
->executeOne();
}
diff --git a/src/applications/maniphest/conduit/ManiphestInfoConduitAPIMethod.php b/src/applications/maniphest/conduit/ManiphestInfoConduitAPIMethod.php
--- a/src/applications/maniphest/conduit/ManiphestInfoConduitAPIMethod.php
+++ b/src/applications/maniphest/conduit/ManiphestInfoConduitAPIMethod.php
@@ -33,6 +33,7 @@
->setViewer($request->getUser())
->withIDs(array($task_id))
->needSubscriberPHIDs(true)
+ ->needProjectPHIDs(true)
->executeOne();
if (!$task) {
throw new ConduitException('ERR_BAD_TASK');
diff --git a/src/applications/maniphest/conduit/ManiphestQueryConduitAPIMethod.php b/src/applications/maniphest/conduit/ManiphestQueryConduitAPIMethod.php
--- a/src/applications/maniphest/conduit/ManiphestQueryConduitAPIMethod.php
+++ b/src/applications/maniphest/conduit/ManiphestQueryConduitAPIMethod.php
@@ -61,10 +61,10 @@
}
protected function execute(ConduitAPIRequest $request) {
- $query = new ManiphestTaskQuery();
-
- $query->setViewer($request->getUser());
- $query->needSubscriberPHIDs(true);
+ $query = id(new ManiphestTaskQuery())
+ ->setViewer($request->getUser())
+ ->needProjectPHIDs(true)
+ ->needSubscriberPHIDs(true);
$task_ids = $request->getValue('ids');
if ($task_ids) {
diff --git a/src/applications/maniphest/conduit/ManiphestUpdateConduitAPIMethod.php b/src/applications/maniphest/conduit/ManiphestUpdateConduitAPIMethod.php
--- a/src/applications/maniphest/conduit/ManiphestUpdateConduitAPIMethod.php
+++ b/src/applications/maniphest/conduit/ManiphestUpdateConduitAPIMethod.php
@@ -34,19 +34,16 @@
throw new Exception("Specify exactly one of 'id' and 'phid'.");
}
+ $query = id (new ManiphestTaskQuery())
+ ->setViewer($request->getUser())
+ ->needSubscriberPHIDs(true)
+ ->needProjectPHIDs(true);
if ($id) {
- $task = id(new ManiphestTaskQuery())
- ->setViewer($request->getUser())
- ->withIDs(array($id))
- ->needSubscriberPHIDs(true)
- ->executeOne();
+ $query->withIDs(array($id));
} else {
- $task = id(new ManiphestTaskQuery())
- ->setViewer($request->getUser())
- ->withPHIDs(array($phid))
- ->needSubscriberPHIDs(true)
- ->executeOne();
+ $query->withPHIDs(array($phid));
}
+ $task = $query->executeOne();
$params = $request->getAllParameters();
unset($params['id']);
diff --git a/src/applications/maniphest/controller/ManiphestBatchEditController.php b/src/applications/maniphest/controller/ManiphestBatchEditController.php
--- a/src/applications/maniphest/controller/ManiphestBatchEditController.php
+++ b/src/applications/maniphest/controller/ManiphestBatchEditController.php
@@ -19,6 +19,7 @@
PhabricatorPolicyCapability::CAN_EDIT,
))
->needSubscriberPHIDs(true)
+ ->needProjectPHIDs(true)
->execute();
$actions = $request->getStr('actions');
diff --git a/src/applications/maniphest/controller/ManiphestReportController.php b/src/applications/maniphest/controller/ManiphestReportController.php
--- a/src/applications/maniphest/controller/ManiphestReportController.php
+++ b/src/applications/maniphest/controller/ManiphestReportController.php
@@ -396,6 +396,12 @@
->setViewer($user)
->withStatuses(ManiphestTaskStatus::getOpenStatusConstants());
+ switch ($this->view) {
+ case 'project':
+ $query->needProjectPHIDs(true);
+ break;
+ }
+
$project_phid = $request->getStr('project');
$project_handle = null;
if ($project_phid) {
diff --git a/src/applications/maniphest/controller/ManiphestSubpriorityController.php b/src/applications/maniphest/controller/ManiphestSubpriorityController.php
--- a/src/applications/maniphest/controller/ManiphestSubpriorityController.php
+++ b/src/applications/maniphest/controller/ManiphestSubpriorityController.php
@@ -13,6 +13,7 @@
$task = id(new ManiphestTaskQuery())
->setViewer($user)
->withIDs(array($request->getInt('task')))
+ ->needProjectPHIDs(true)
->requireCapabilities(
array(
PhabricatorPolicyCapability::CAN_VIEW,
diff --git a/src/applications/maniphest/controller/ManiphestTaskEditController.php b/src/applications/maniphest/controller/ManiphestTaskEditController.php
--- a/src/applications/maniphest/controller/ManiphestTaskEditController.php
+++ b/src/applications/maniphest/controller/ManiphestTaskEditController.php
@@ -39,6 +39,7 @@
))
->withIDs(array($this->id))
->needSubscriberPHIDs(true)
+ ->needProjectPHIDs(true)
->executeOne();
if (!$task) {
return new Aphront404Response();
@@ -446,6 +447,7 @@
->setViewer($user)
->withIDs(array($template_id))
->needSubscriberPHIDs(true)
+ ->needProjectPHIDs(true)
->executeOne();
if ($template_task) {
$cc_phids = array_unique(array_merge(
diff --git a/src/applications/maniphest/controller/ManiphestTransactionSaveController.php b/src/applications/maniphest/controller/ManiphestTransactionSaveController.php
--- a/src/applications/maniphest/controller/ManiphestTransactionSaveController.php
+++ b/src/applications/maniphest/controller/ManiphestTransactionSaveController.php
@@ -10,6 +10,7 @@
->setViewer($user)
->withIDs(array($request->getStr('taskID')))
->needSubscriberPHIDs(true)
+ ->needProjectPHIDs(true)
->executeOne();
if (!$task) {
return new Aphront404Response();
diff --git a/src/applications/maniphest/editor/ManiphestTransactionEditor.php b/src/applications/maniphest/editor/ManiphestTransactionEditor.php
--- a/src/applications/maniphest/editor/ManiphestTransactionEditor.php
+++ b/src/applications/maniphest/editor/ManiphestTransactionEditor.php
@@ -370,6 +370,7 @@
->setViewer($this->getActor())
->withPHIDs($blocked_phids)
->needSubscriberPHIDs(true)
+ ->needProjectPHIDs(true)
->execute();
$old = $unblock_xaction->getOldValue();
diff --git a/src/applications/maniphest/event/ManiphestHovercardEventListener.php b/src/applications/maniphest/event/ManiphestHovercardEventListener.php
--- a/src/applications/maniphest/event/ManiphestHovercardEventListener.php
+++ b/src/applications/maniphest/event/ManiphestHovercardEventListener.php
@@ -25,6 +25,7 @@
return;
}
+ $e_project = PhabricatorProjectObjectHasProjectEdgeType::EDGECONST;
// Fun with "Unbeta Pholio", hua hua
$e_dep_on = PhabricatorEdgeConfig::TYPE_TASK_DEPENDS_ON_TASK;
$e_dep_by = PhabricatorEdgeConfig::TYPE_TASK_DEPENDED_ON_BY_TASK;
@@ -33,6 +34,7 @@
->withSourcePHIDs(array($phid))
->withEdgeTypes(
array(
+ $e_project,
$e_dep_on,
$e_dep_by,
));
@@ -40,12 +42,10 @@
$edge_phids = $edge_query->getDestinationPHIDs();
$owner_phid = $task->getOwnerPHID();
- $project_phids = $task->getProjectPHIDs();
$phids = array_filter(array_merge(
array($owner_phid),
- $edge_phids,
- $project_phids));
+ $edge_phids));
$viewer_handles = $this->loadHandles($phids, $viewer);
@@ -58,17 +58,12 @@
}
$hovercard->addField(pht('Assigned to'), $owner);
- if ($project_phids) {
- $hovercard->addField(pht('Projects'),
- implode_selected_handle_links(', ', $viewer_handles, $project_phids));
- }
if ($edge_phids) {
$edge_types = array(
- PhabricatorEdgeConfig::TYPE_TASK_DEPENDED_ON_BY_TASK
- => pht('Dependent Tasks'),
- PhabricatorEdgeConfig::TYPE_TASK_DEPENDS_ON_TASK
- => pht('Depends On'),
+ $e_project => pht('Projects'),
+ $e_dep_by => pht('Dependent Tasks'),
+ $e_dep_on => pht('Depends On'),
);
$max_count = 6;
diff --git a/src/applications/maniphest/mail/ManiphestTaskMailReceiver.php b/src/applications/maniphest/mail/ManiphestTaskMailReceiver.php
--- a/src/applications/maniphest/mail/ManiphestTaskMailReceiver.php
+++ b/src/applications/maniphest/mail/ManiphestTaskMailReceiver.php
@@ -18,6 +18,7 @@
->setViewer($viewer)
->withIDs(array($id))
->needSubscriberPHIDs(true)
+ ->needProjectPHIDs(true)
->execute();
return head($results);
diff --git a/src/applications/maniphest/query/ManiphestTaskQuery.php b/src/applications/maniphest/query/ManiphestTaskQuery.php
--- a/src/applications/maniphest/query/ManiphestTaskQuery.php
+++ b/src/applications/maniphest/query/ManiphestTaskQuery.php
@@ -51,6 +51,7 @@
const ORDER_TITLE = 'order-title';
private $needSubscriberPHIDs;
+ private $needProjectPHIDs;
const DEFAULT_PAGE_SIZE = 1000;
@@ -185,6 +186,11 @@
return $this;
}
+ public function needProjectPHIDs($bool) {
+ $this->needProjectPHIDs = $bool;
+ return $this;
+ }
+
public function loadPage() {
// TODO: (T603) It is possible for a user to find the PHID of a project
// they can't see, then query for tasks in that project and deduce the
@@ -340,22 +346,20 @@
protected function didFilterPage(array $tasks) {
$phids = mpull($tasks, 'getPHID');
- // TODO: Eventually, we should make this optional and introduce a
- // needProjectPHIDs() method, but for now there's a lot of code which
- // assumes the data is always populated.
-
- $edge_query = id(new PhabricatorEdgeQuery())
- ->withSourcePHIDs($phids)
- ->withEdgeTypes(
- array(
- PhabricatorProjectObjectHasProjectEdgeType::EDGECONST,
- ));
- $edge_query->execute();
-
- foreach ($tasks as $task) {
- $project_phids = $edge_query->getDestinationPHIDs(
- array($task->getPHID()));
- $task->attachProjectPHIDs($project_phids);
+ if ($this->needProjectPHIDs) {
+ $edge_query = id(new PhabricatorEdgeQuery())
+ ->withSourcePHIDs($phids)
+ ->withEdgeTypes(
+ array(
+ PhabricatorProjectObjectHasProjectEdgeType::EDGECONST,
+ ));
+ $edge_query->execute();
+
+ foreach ($tasks as $task) {
+ $project_phids = $edge_query->getDestinationPHIDs(
+ array($task->getPHID()));
+ $task->attachProjectPHIDs($project_phids);
+ }
}
if ($this->needSubscriberPHIDs) {
diff --git a/src/applications/maniphest/query/ManiphestTaskSearchEngine.php b/src/applications/maniphest/query/ManiphestTaskSearchEngine.php
--- a/src/applications/maniphest/query/ManiphestTaskSearchEngine.php
+++ b/src/applications/maniphest/query/ManiphestTaskSearchEngine.php
@@ -119,7 +119,8 @@
}
public function buildQueryFromSavedQuery(PhabricatorSavedQuery $saved) {
- $query = id(new ManiphestTaskQuery());
+ $query = id(new ManiphestTaskQuery())
+ ->needProjectPHIDs(true);
$author_phids = $saved->getParameter('authorPHIDs');
if ($author_phids) {
diff --git a/src/applications/project/controller/PhabricatorProjectProfileController.php b/src/applications/project/controller/PhabricatorProjectProfileController.php
--- a/src/applications/project/controller/PhabricatorProjectProfileController.php
+++ b/src/applications/project/controller/PhabricatorProjectProfileController.php
@@ -143,6 +143,7 @@
->withAnyProjects(array($project->getPHID()))
->withStatuses(ManiphestTaskStatus::getOpenStatusConstants())
->setOrderBy(ManiphestTaskQuery::ORDER_PRIORITY)
+ ->needProjectPHIDs(true)
->setLimit(10);
$tasks = $query->execute();
diff --git a/src/applications/repository/worker/commitmessageparser/PhabricatorRepositoryCommitMessageParserWorker.php b/src/applications/repository/worker/commitmessageparser/PhabricatorRepositoryCommitMessageParserWorker.php
--- a/src/applications/repository/worker/commitmessageparser/PhabricatorRepositoryCommitMessageParserWorker.php
+++ b/src/applications/repository/worker/commitmessageparser/PhabricatorRepositoryCommitMessageParserWorker.php
@@ -459,6 +459,7 @@
$tasks = id(new ManiphestTaskQuery())
->setViewer($actor)
->withIDs(array_keys($task_statuses))
+ ->needProjectPHIDs(true)
->execute();
foreach ($tasks as $task_id => $task) {
diff --git a/src/applications/search/controller/PhabricatorSearchAttachController.php b/src/applications/search/controller/PhabricatorSearchAttachController.php
--- a/src/applications/search/controller/PhabricatorSearchAttachController.php
+++ b/src/applications/search/controller/PhabricatorSearchAttachController.php
@@ -144,6 +144,7 @@
->setViewer($user)
->withPHIDs(array_keys($phids))
->needSubscriberPHIDs(true)
+ ->needProjectPHIDs(true)
->execute();
if (empty($targets)) {
@@ -158,9 +159,13 @@
$cc_vector = array();
// since we loaded this via a generic object query, go ahead and get the
// attach the cc phids now
$task->attachSubscriberPHIDs(
PhabricatorSubscribersQuery::loadSubscribersForPHID($task->getPHID()));
+ $task->attachProjectPHIDs(
+ PhabricatorEdgeQuery::loadDestinationPHIDs($task->getPHID(),
+ PhabricatorProjectObjectHasProjectEdgeType::EDGECONST));
+
$cc_vector[] = $task->getSubscriberPHIDs();
foreach ($targets as $target) {
$cc_vector[] = $target->getSubscriberPHIDs();
@@ -158,9 +159,13 @@
$cc_vector = array();
// since we loaded this via a generic object query, go ahead and get the
- // attach the cc phids now
+ // attach the subscriber and project phids now
$task->attachSubscriberPHIDs(
PhabricatorSubscribersQuery::loadSubscribersForPHID($task->getPHID()));

File Metadata

Mime Type
text/plain
Expires
Wed, Mar 19, 5:13 PM (2 w, 3 d ago)
Storage Engine
blob
Storage Format
Encrypted (AES-256-CBC)
Storage Handle
7224791
Default Alt Text
D11004.diff (14 KB)

Event Timeline